#ifndef NT2_INCLUDE_FUNCTIONS_LOGICAL_ORNOT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LOGICAL_ORNOT_HPP_INCLUDED

#include <nt2/boolean/include/functions/logical_ornot.hpp>

#endif
